AuthResult class
Strongly-typed result of a single authentication attempt.
Constructors
- AuthResult({required AuthResultCode code, required String message, required AuthType type})
-
const
-
AuthResult.fromMap(Map<
Object?, Object?> map) -
factory
Properties
- code → AuthResultCode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCanceled → bool
-
True when the user explicitly dismissed / pressed Cancel or Back.
no setter
- isLockedOut → bool
-
True when too many failed attempts have locked the sensor.
no setter
- isSuccess → bool
-
no setter
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AuthType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited